# lib.py

import cv2
import numpy as np

def is_image_blurry_laplacian(image, threshold=600):
    gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
    laplacian_var = cv2.Laplacian(gray, cv2.CV_64F).var()
    return (laplacian_var < threshold, laplacian_var)

def is_image_blurry_sobel(image, threshold=50):
    gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
    gradient_x = cv2.Sobel(gray, cv2.CV_64F, 1, 0, ksize=3)
    gradient_y = cv2.Sobel(gray, cv2.CV_64F, 0, 1, ksize=3)
    gradient_magnitude = np.sqrt(gradient_x**2 + gradient_y**2)
    return (gradient_magnitude.mean() < threshold, gradient_magnitude.mean())

def is_image_blurry_fourier(image, threshold=10000):
    gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
    f_transform = np.fft.fft2(gray)
    f_transform_shifted = np.fft.fftshift(f_transform)
    magnitude_spectrum = np.abs(f_transform_shifted)
    return (magnitude_spectrum.mean() < threshold, magnitude_spectrum.mean())

def is_image_blurry(image, algorithm='laplacian', threshold=600):
    if algorithm == 'laplacian':
        return is_image_blurry_laplacian(image, threshold)
    elif algorithm == 'sobel':
        return is_image_blurry_sobel(image, threshold)
    elif algorithm == 'fourier':
        return is_image_blurry_fourier(image, threshold)
    else:
        raise ValueError(f"Invalid algorithm: {algorithm}")
